@@ -60,7 +60,6 @@
 #include <wpe/WebKitColor.h>
 #include <wpe/WebKitRectangle.h>
 #include <wpe/WebKitWebViewBackend.h>
-#include <wpe/wpe-platform.h>
 
 G_BEGIN_DECLS
 
@@ -337,14 +336,6 @@ webkit_web_view_new                                  (WebKitWebViewBackend
 WEBKIT_API WebKitWebViewBackend *
 webkit_web_view_get_backend                          (WebKitWebView             *web_view);
 
-WEBKIT_API WPEDisplay *
-webkit_web_view_get_display                          (WebKitWebView             *web_view);
-
-WEBKIT_API WPEView *
-webkit_web_view_get_wpe_view                         (WebKitWebView             *web_view);
-
-WEBKIT_API void
-webkit_web_view_toggle_inspector                     (WebKitWebView             *web_view);
 
 
 WEBKIT_API gboolean
